//  Copyright 2021 Aaron Hance
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

{ 
	Driver->Storage->Include->storagetypes - Structs & Data Shared Across Storage Drivers.
	
	@author(Aaron Hance <ah@aaronhance.me>)
}
unit storagetypes;

interface

uses
    lists;

type

    TControllerType = (
        ControllerATA, 
        ControllerATAPI,
        ControllerUSB,
        ControllerAHCI,
        ControllerAHCI_ATAPI,
        ControllerNVMe,
        ControllerNET, 
        ControllerRAM,
        ControllerSCSI
        );

    TFileSystemType = (
        FileSystemFAT32,
        FileSystemExFAT,
        FileSystemEXT,
        FileSystemEXT2,
        FileSystemCDFS,
        FileSystemOther
        );

    PStorage_device = ^TStorage_Device;
    PDrive_Error    = ^TDrive_Error;

    PPHIOHook = procedure(drive : PStorage_device; addr : uint32; sectors : uint32; buffer : puint32);
    PPHIOHook_ = procedure;

    byteArray8 = array[0..7] of char;
    PByteArray8 = ^byteArray8;

    { Generic storage device }
    TStorage_Device = record
        id               : uint8;
        controller       : TControllerType;
        controllerId0    : uint32;
        writable         : boolean;
        volumes          : PDList;
        writeCallback    : PPHIOHook;
        readCallback     : PPHIOHook;
        maxSectorCount   : uint32; 
        sectorSize       : uint32; //in bytes
        start            : uint32; //start of device in sectors
    end;

    { Generic storage volume }
    TStorage_Volume = record
        id         : uint32;
        device     : PStorage_device;
        name       : pchar;
        fileSystem : TFileSystemType;
        size       : uint32; //size of volume in sectors
        start      : uint32; //start of volume in sectors
    end;

    PStorage_Volume = ^TStorage_Volume;

    TDrive_Error = record 
        code : uint16;
        description : pchar;
        recoverable : boolean;
    end;


implementation


end.
